-- if the table exists, drop it so we can reload it
DROP TEMPORARY TABLE IF EXISTS s70;

-- create the table with the following fields
CREATE TEMPORARY TABLE s70 (
	file_id SMALLINT UNSIGNED AUTO_INCREMENT,
	filename VARCHAR(30),
	fileloc VARCHAR(100),
	hdrver VARCHAR(10),
	survey VARCHAR(10),
	src_name VARCHAR(20),
	telescope VARCHAR(16),
	data_type VARCHAR(16),
	raj VARCHAR(15),
	decj VARCHAR(15),
	rajd DOUBLE,
	decjd DOUBLE,
	gl DECIMAL(9,4),
	gb DECIMAL(9,4),
	bmaj FLOAT,
	bmin FLOAT,
	bpa FLOAT,
	date_obs VARCHAR(30),
	mjd DOUBLE,
	obsfreq DOUBLE,
	chanbw DOUBLE,
	nchan INT,
	scanlen DOUBLE,
	tsamp DOUBLE,
	nbits INT,
	PRIMARY KEY (file_id)
);

-- now load the data from the file in $PVO. It is a csv file, and the
-- strings in it are enclosed by ". We don't want the quote marks in
-- the table, so the "OPTIONALLY ENCLOSED BY" statement will remove
-- them
LOAD DATA LOCAL
INFILE "/DATA/SITAR_1/whi550/VO/PulsarVO/s70v_summary_sf.csv"
INTO TABLE s70
FIELDS TERMINATED BY ","
OPTIONALLY ENCLOSED BY "\""
IGNORE 1 LINES  -- this ignores the first line in the csv file which contains the column headers.
(filename,fileloc,hdrver,survey,src_name,telescope,data_type,raj,decj,rajd,decjd,gl,gb,bmaj,bmin,bpa,date_obs,mjd,obsfreq,chanbw,nchan,scanlen,tsamp,nbits);

-- -- add gl and gb columns to the table.
-- -- SET @ngpra=192.859508, @ngpdec=27.128336, @ascnode=32.932; -- base coords for galactic coord transformation.
